<?php

/**
 * @file
 * Plugin who deals with alters functions.
 */

$plugin = array(
  'name' => 'Alters',
  'description' => 'Displays informations about defined alters.',
  'render callbacks' => array(
    '_moduleinfo_alters_defined' => t('Alters'),
  ),
);

/**
 * Renders informations about functions who are alter functions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_alters_defined($module_name = NULL) {
  $result = _moduleinfo_cache_read('def functions', $module_name);

  if (!count($result)) {
    return drupal_goto('moduleinfo/scan', array('query' => array('destination' => drupal_get_path_alias($_GET['q']))));
  }

  $items = array();
  foreach ($result as $module) {
    foreach ($module->data as $alters => $info) {
      if (is_null($module_name)) {
        if (!preg_match('/_alter$/i', $alters)) {
          continue;
        }
      }
      else {
        if (!preg_match('/^(' . $module_name . ')_(.*)_alter$/i', $alters)) {
          continue;
        }
      }

      $items[$alters] = array(
        'info' => '<span class="mono">' . $info['signature'] . '</span>',
        'desc' => $info['shortinfo'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all functions which end in *_alter*.');

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('Alters'),
    '#description' => $description,
  ));
}
