<?php

/**
 * @file
 * Plugin who deals with hook block_info.
 */

$plugin = array(
  'name' => 'cTools Plugin',
  'description' => 'Displays all defined plugins for the ctools plugin system.',
  'render callbacks' => array(
    '_moduleinfo_ctools_plugins_defined' => t('Defined accepted cTools Plugins'),
    '_moduleinfo_ctools_plugins_provided' => t('Defined cTools Plugins'),
  ),
);

/**
 * Renders informations to accepted plugins.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_ctools_plugins_defined($module_name = NULL) {
  $all_info = ctools_plugin_get_plugin_type_info();

  if (!is_null($module_name) && !in_array($module_name, array_keys($all_info))) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name => $all_info[$module_name]);

    $items = array();
    foreach ($list as $module_name => $def) {
      foreach ($def as $plugin => $info) {
        $items[] = array(
          'info' => '<span class="mono">' . $plugin . '</span>',
        );
      }
    }
  }
  else {
    $list = $all_info;

    $items = array();
    foreach ($list as $module_name => $def) {
      $plugs = array();
      foreach ($def as $plugin => $info) {
        $plugs[] = array(
          'info' => $plugin,
        );
      }
      $items[] = array(
        'info' => '<span class="mono">' . $module_name . '</span>',
        'desc' => _moduleinfo_helper_itemlist($plugs),
      );
    }
  }


  $description = t('Lists all plugins from the ctools plugin system, which this module accepts.');
  if (is_null($module_name)) {
    $description = t('Lists all plugins by module from the ctools plugin system, which are accepted by modules.');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('cTools Plugins'),
    '#description' => $description,
  ));
}

/**
 * Renders informations to provided plugins.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_ctools_plugins_provided($module_name = NULL) {
  $all_info = ctools_plugin_get_plugin_type_info();

  ctools_include('plugins');

  $items = array();

  if (is_null($module_name)) {
    foreach ($all_info as $module => $def) {
      $plugin = key($def);
      $plugins = ctools_get_plugins($module, $plugin);

      foreach ($plugins as $name => $info) {
        $items[] = array(
          'info' => '<span class="mono">' . $info['module'] . ' - ' . $info['name'] . ' <span class="description">(' . $name . ')</span></span>',
          'desc' => '<span class="description">' . $info['path'] . '/' . $info['file'] . '</span>',
        );
      }
    }
  }
  else {
    if (!isset($all_info[$module_name])) {
      return '';
    }

    foreach ($all_info[$module_name] as $plugin => $def) {
      $plugins = ctools_get_plugins($module_name, $plugin);

      foreach ($plugins as $name => $info) {
        $items[] = array(
          'info' => '<span class="mono">' . $info['name'] . ' <span class="description">(' . $name . ')</span></span>',
          'desc' => '<span class="description">' . $info['path'] . '/' . $info['file'] . '</span>',
        );
      }
    }
  }

  $description = t('Lists all plugins from the ctools plugin system, which this module provides.');
  if (is_null($module_name)) {
    $description = t('Lists all plugins by module from the ctools plugin system, which are provided by modules.');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('cTools Plugins'),
    '#description' => $description,
  ));
}
