<?php

/**
 * @file
 * Plugin who deals with hook action_info.
 */

$plugin = array(
  'name' => 'Field Info Hooks',
  'description' => 'Displays all defined hook_action_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_action_info_defined' => t('Defined Action Info Hooks'),
  ),
);

/**
 * Renders informations to exposed actions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_action_info_defined($module_name = NULL) {
  $list = module_implements('action_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_action_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $key => $values) {
      $items[] = array(
        'info' => '<span class="mono">' . $key . '</span>',
        'desc' => '<b>' . t('Type') . ' : ' . $values['type'] . '</b> ' . $values['label'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all actions defined via hook_action_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all actions defined via hook_action_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_action_info'),
    '#description' => $description,
  ));
}
