<?php

/**
 * @file
 * Plugin who deals with hook entity_info.
 */

$plugin = array(
  'name' => 'Entity Info Hooks',
  'description' => 'Displays all defined hook_entity_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_entity_info_defined' => t('Defined Entity Info Hooks'),
  ),
);

/**
 * Renders informations to exposed entities.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_entity_info_defined($module_name = NULL) {
  $list = module_implements('entity_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_entity_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $entity => $values) {
      $subitems = '';
      if (isset($values['bundles'])) {
        $subitems = array();
        foreach ($values['bundles'] as $key => $elem) {
          $subitems[] = array(
            'info' => '<span class="mono">' . $key . '</span>',
            'desc' => $elem['label'],
          );
        }
        $subitems = _moduleinfo_helper_itemlist($subitems);
      }
      $items[] = array(
        'info' => '<span class="mono">' . $entity . '</span>',
        'desc' => trim($values['label'] . ' ' . $subitems),
      );
    }
  }

  ksort($items);

  $description = t('Lists all entities defined via hook_entity_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all entities defined via hook_entity_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_entity_info'),
    '#description' => $description,
  ));
}
