<?php

/**
 * @file
 * Plugin who deals with hook field_formatter_info.
 */

$plugin = array(
  'name' => 'Field Formatter Info Hooks',
  'description' => 'Displays all defined hook_field_formatter_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_field_formatter_info_defined' => t('Defined Field Formatter Info Hooks'),
  ),
);

/**
 * Renders informations to exposed field formatters.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_field_formatter_info_defined($module_name = NULL) {
  $list = module_implements('field_formatter_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_field_formatter_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $key => $values) {
      $items[] = array(
        'info' => $values['label'],
        'desc' => (isset($values['description']) ? '<b>' . $values['description'] . '</b> ' : '')  . implode(', ', $values['field types']),
      );
    }
  }

  ksort($items);

  $description = t('Lists all field formatters defined via hook_field_formatter_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all field formatters defined via hook_field_formatter_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_field_formatter_info'),
    '#description' => $description,
  ));
}
