<?php

/**
 * @file
 * Plugin who deals with hook filter_info.
 */

$plugin = array(
  'name' => 'Filter Info Hooks',
  'description' => 'Displays all defined hook_filter_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_filter_info_defined' => t('Defined Filter Info Hooks'),
  ),
);

/**
 * Renders informations to exposed filters.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_filter_info_defined($module_name = NULL) {
  $list = module_implements('filter_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_filter_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $key => $values) {
      $items[] = array(
        'info' => '<b class="mono">' . $key . '</b>',
        'desc' => trim('<b>' . $values['title'] . '</b> ' . (isset($values['description']) ? $values['description'] : '')),
      );
    }
  }

  $description = t('Lists all filters defined via hook_filter_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all filters defined via hook_filter_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_filter_info'),
    '#description' => $description,
  ));
}
