<?php

/**
 * @file
 * Plugin who deals with hook block_info.
 */

$plugin = array(
  'name' => 'Hook Info Hooks',
  'description' => 'Displays all defined hook_hook_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_hook_info_defined' => t('Defined Hook Info Hooks'),
  ),
);

/**
 * Renders informations to exposed blocks.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_hook_info_defined($module_name = NULL) {
  $list = module_implements('hook_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_hook_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $hook => $values) {
      $items[] = array(
        'info' => '<span class="mono">' . $hook . '</span>',
        'desc' => t('Group: ') . $values['group'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all hooks defined via hook_hook_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all hooks defined via hook_hook_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_hook_info'),
    '#description' => $description,
  ));
}
