<?php

/**
 * @file
 * Plugin who deals with theme hooks and theme functions.
 */

$plugin = array(
  'name' => 'Theme Hooks',
  'description' => 'Displays all defined hook_theme().',
  'render callbacks' => array(
    '_moduleinfo_hook_theme_defined' => t('Defined Theme Hooks'),
    '_moduleinfo_hook_theme_parsed' => t('Parsed Theme Hooks'),
  ),
);

/**
 * Renders informations to exposed theme hooks.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_theme_defined($module_name = NULL) {
  $list = module_implements('theme');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_theme';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $theme => $values) {
      $tmp = array(
        'info' => '<span class="mono">theme_' . $theme . '</span>',
      );

      $template = '';
      if (isset($values['template'])) {
        $template = '<b class="mono">' . t('Template') . ':</b> ' . $values['template'] . '.tpl.php';
      }
      $file = '';
      if (isset($values['file'])) {
        $file = '<b class="mono">' . t('Required file') . ':</b> ' . $values['file'];
      }

      $tmp['desc'] = trim($template . ' ' . $file);

      $items[] = $tmp;
    }
  }

  $description = t('Lists all themes defined via hook_theme() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all themes defined via hook_theme().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_theme'),
    '#description' => $description,
  ));
}

/**
 * Renders informations to implemented theme_...() functions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_theme_parsed($module_name = NULL) {
  $funcs = _moduleinfo_cache_read('def functions', $module_name);

  if (!count($funcs)) {
    return '';
  }

  $items = array();
  foreach ($funcs as $module_name => $cache) {
    foreach ($cache->data as $function_name => $info) {
      if (strpos($function_name, 'theme_') !== 0) {
        continue;
      }

      $items[$function_name] = array(
        'info' => '<span class="mono">' . $info['signature'] . '</span>',
        'desc' => $info['shortinfo'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all Themes defined via hook_theme() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all Themes defined via hook_theme().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('theme_functions'),
    '#description' => $description,
  ));
}
