<?php

/**
 * @file
 * Plugin who deals with hook token_info.
 */

$plugin = array(
  'name' => 'Field Info Hooks',
  'description' => 'Displays all defined hook_token_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_token_info_defined' => t('Defined Token Info Hooks'),
  ),
);

/**
 * Renders informations to exposed token.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_token_info_defined($module_name = NULL) {
  $list = module_implements('token_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_token_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    if (count($data['tokens'])) {
      foreach ($data['tokens'] as $prefix => $token) {
        foreach ($token as $key => $setup) {
          $items[] = array(
            'info' => '<span class="mono">[' . $prefix . ':' . $key . ']</span>',
            'desc' => '<b>' . $setup['name'] . '</b> ' . $setup['description'],
          );
        }
      }
    }
  }

  ksort($items);

  $description = t('Lists all tokens defined via hook_token_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all tokens defined via hook_token_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_token_info'),
    '#description' => $description,
  ));
}
