<?php

/**
 * @file
 * Plugin who deals with hook trigger_info.
 */

$plugin = array(
  'name' => 'Trigger Info Hooks',
  'description' => 'Displays all defined hook_trigger_info().',
  'render callbacks' => array(
    '_moduleinfo_hook_trigger_info_defined' => t('Defined Trigger Info Hooks'),
  ),
);

/**
 * Renders informations to exposed triggers.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_hook_trigger_info_defined($module_name = NULL) {
  $list = module_implements('trigger_info');

  if (!is_null($module_name) && !in_array($module_name, $list)) {
    return '';
  }

  if (!is_null($module_name)) {
    $list = array($module_name);
  }

  $items = array();
  foreach ($list as $module_name) {
    $function = $module_name . '_trigger_info';
    if (!function_exists($function)) {
      continue;
    }
    $data = $function(NULL, NULL, NULL, NULL, NULL, NULL, NULL);

    foreach ($data as $values) {
      foreach ($values as $trigger => $setup) {
        $items[] = array(
          'info' => '<b class="mono">' . $trigger . '</b>',
          'desc' => isset($values['label']) ? $values['label'] : '',
        );
      }
    }
  }

  $description = t('Lists all triggers defined via hook_trigger_info() of that module.');
  if (is_null($module_name)) {
    $description = t('Lists all triggers defined via hook_trigger_info().');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('hook_trigger_info'),
    '#description' => $description,
  ));
}
