<?php

/**
 * @file
 * Plugin who deals with functions which invoke something.
 */

$plugin = array(
  'name' => 'Invoke Functions',
  'description' => 'Scans Drupal for positions where a function with namecontent *invoke* is called.',
  'scan callbacks' => array(
    '_moduleinfo_scan_invokes' => array(
      'scan' => array(
        '/.*/i',
      ),
      'skip' => array(
        '/.+\.tpl\.php$/i',
        '/.+\.api\.php$/i',
      ),
    ),
  ),
  'render callbacks' => array(
    '_moduleinfo_invokes_called' => t('Found called Invokes'),
    '_moduleinfo_invokes_defined' => t('Functions to Invoke Something'),
  ),
  '#weight' => -8,
);

/**
 * Scans files for informations about functions which invoke something.
 *
 * @param string $module_name
 *   Name of the current module
 * @param string $content
 *   Content of the current processed file
 * @param string $uri
 *   URI of the file.
 */
function _moduleinfo_scan_invokes($module_name, $content, $uri) {
  return;

  $ref = new PhpReflector($content);
  $ref->parse();
  $symbols = $ref->getResult();

  if (!isset($symbols['called functions'])) {
    return;
  }

  $functions = $symbols['defined functions'];

  $hits = array();
  foreach ($functions as $i => $info) {
    if (strpos($info->name, 'invoke') !== FALSE) {
      $functions[$i]->file = $uri;
      $hits[$info->name] = $functions[$i];
    }
  }

  if (count($hits)) {
    _moduleinfo_cache_write('invokes', $hits, $module_name);
  }
}

/**
 * Renders informations about called invoke functions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_invokes_called($module_name = NULL) {
  return '';
}

/**
 * Renders informations about defined invoke functions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_invokes_defined($module_name = NULL) {
  $result = _moduleinfo_cache_read('all functions');

  if (!count($result)) {
    return '';
  }

  $functions = array_keys($result['0']->data);

  $invokes = array_filter($functions, '_moduleinfo_invokes_filter');
  $invokes = array_values($invokes);
  $invokes[] = 'module_invoke_all';
  $invokes[] = 'module_invoke';
  $invokes[] = 'ajax_command_invoke';
  $invokes[] = 'bootstrap_invoke_all';
  $invokes[] = 'image_toolkit_all';
  $invokes[] = 'language_provider_invoke';

  return '';
}

/**
 * Helper for a uasort filter.
 */
function _moduleinfo_invokes_filter($elem) {
  return strpos($elem, 'invoke') !== FALSE;
}
