<?php

/**
 * @file
 * Plugin who deals with preprocess hooks.
 */

$plugin = array(
  'name' => 'Preprocess HOOKs',
  'description' => 'Scans Drupal for defined preprocess HOOKs',
  'scan callbacks' => array(),
  'render callbacks' => array(
    '_moduleinfo_preprocess_defined' => t('Preprocess Hooks'),
  ),
);

/**
 * Renders informations about implemented preprocess functions.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_preprocess_defined($module_name = NULL) {
  $result = _moduleinfo_cache_read('def functions', $module_name);

  if (!count($result)) {
    return drupal_goto('moduleinfo/scan', array('query' => array('destination' => drupal_get_path_alias($_GET['q']))));
  }

  $items = array();
  foreach ($result as $module) {
    foreach ($module->data as $preprocess => $info) {
      if (!preg_match('/^(template|' . $module_name . ')_preprocess_/i', $preprocess)) {
        continue;
      }

      $items[] = array(
        'info' => '<span class="mono">' . $preprocess . '</span>',
        'desc' => $info['shortinfo'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all preprocess hooks of that module based on *_preprocess_* as signature part.');
  if (is_null($module_name)) {
    $description = t('Lists all preprocess hooks of the system based on *_preprocess_* as signature part.');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('Preproccess Functions'),
    '#description' => $description,
  ));
}
