<?php

/**
 * @file
 * Plugin who deals with schema definitions.
 */


$plugin = array(
  'name' => 'Schema',
  'description' => 'Shows the current schema definitions for a certain module.',
  'render callbacks' => array(
    '_moduleinfo_schema_defined' => t('Schema as defined by the hook_schema().'),
  ),
);

/**
 * Renders informations about the db schema of a module.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_schema_defined($module_name = NULL) {
  if (is_null($module_name)) {
    $result = _moduleinfo_cache_read('all files');
    $cache_key = '0';
  }
  else {
    $result = _moduleinfo_cache_read('files', $module_name);
    $cache_key = $module_name;
  }

  if (!count($result)) {
    return '';
  }

  $files = $result[$cache_key]->data;

  $items = array();
  foreach ($files as $file => $info) {
    if (!preg_match('/\.install$/ui', $file)) {
      continue;
    }

    if (is_string($info)) {
      $module_name = $info;
    }

    include_once $file;

    $schema_function = $module_name . '_schema';

    if (!function_exists($schema_function)) {
      continue;
    }

    $schema = $schema_function();

    ksort($schema);

    foreach ($schema as $table => $setup) {
      $tmp = array(
        'info' => '<span class="mono">' . $table . '</span>',
      );

      $description = '';
      if (isset($setup['description'])) {
        $description = $setup['description'];
      }

      $fields = '';
      if (isset($setup['fields'])) {
        $elems = array();
        foreach ($setup['fields'] as $field => $def) {
          $elems[$field] = array(
            'info' => trim('<span class="mono">' . $field . '</span> ' . (isset($def['description']) ? '<span class="info">' . $def['description'] . '</span>' : '')),
          );
        }

        ksort($elems);

        $fields = _moduleinfo_helper_itemlist($elems);
      }

      if (!empty($fields) || !empty($description)) {
        $tmp['desc'] = $description . ' ' . $fields;
      }

      $items[$table] = $tmp;
    }
  }

  ksort($items);

  $description = t('Lists all tables and fields of this certain module This is the unprocessed and unaltered view at the schema definition array.');
  if (is_null($module_name)) {
    $description = t('Lists all paths defined via hook_schema() unprocessed and unaltered.');
  }

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('Schema'),
    '#description' => $description,
  ));
}
