<?php

/**
 * @file
 * Plugin who deals with update definitions.
 */

$plugin = array(
  'name' => 'Update',
  'description' => 'Shows how many update_N() functions are defined for a certain module and if available the short information what this update does.',
  'render callbacks' => array(
    '_moduleinfo_updates_defined' => t('Updates, as defined by hook_update_N()'),
  ),
);

/**
 * Renders informations about defined updates.
 *
 * @param string $module_name
 *   Name of the module to display.
 *
 * @return string
 *   Rendered informations.
 */
function _moduleinfo_updates_defined($module_name = NULL) {
  if (is_null($module_name)) {
    return '';
  }

  $result = _moduleinfo_cache_read('def functions', $module_name);

  if (!count($result)) {
    drupal_goto('moduleinfo/scan', array('query' => array('destination' => drupal_get_path_alias($_GET['q']))));
  }

  $items = array();
  foreach ($result as $module) {
    foreach ($module->data as $update => $info) {
      if (!preg_match('/^(' . $module_name . ')_update_([0-9]+)/i', $update)) {
        continue;
      }

      $items[$update] = array(
        'info' => '<span class="mono">' . $update . '</span>',
        'desc' => $info['shortinfo'],
      );
    }
  }

  ksort($items);

  $description = t('Lists all updates hook_update_N() of that module.');

  return _moduleinfo_helper_fieldset($items, array(
    '#title' => t('Updates'),
    '#description' => $description,
  ));
}
